#
# spec file for package erlang-rebar
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           erlang-rebar
%define normal_build    ("%{name}" == "erlang-rebar")
%define testsuite_build ("%{name}" == "erlang-rebar-testsuite")
Version:        2.6.4+git20180201.b6d3094
Release:        6.2
%define mod_ver %(echo "%{version}" | cut -d "+" -f1)
Summary:        A sophisticated build-tool for Erlang projects that follows OTP principles
License:        Apache-2.0
Group:          Development/Tools/Building
URL:            https://github.com/rebar/rebar
Source:         rebar-%{version}.tar.bz2
Source1:        macros.erlang-rebar
Source98:       %{name}.rpmlintrc
Patch2:         tdeps_update-retest.patch
Patch5:         erlc_dep_graph-timeout.patch
# PATCH-FIX-OPENSUSE -- bmwiedemann
Patch6:         reproducible.patch
Patch7:         rebar-0014-erl_interface-was-removed-in-Erlang-23.patch
Patch8:         0001-Fix-rebar-xref-for-recent-Erlang.patch
BuildRequires:  erlang >= 26
%if 0%{?suse_version} > 1320
BuildRequires:  strip-nondeterminism
%endif
Requires:       erlang >= 26
Provides:       rebar = %{version}
Obsoletes:      rebar < %{version}
%if %{testsuite_build}
# for 'make test'
BuildRequires:  erlang-rebar = %{version}
BuildRequires:  erlang-reltool
BuildRequires:  erlang-retest >= 1.1.0
BuildRequires:  git
BuildRequires:  mercurial
%if "%{_repository}" == "standard"
ExclusiveArch:  do-not-build
%endif
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%if 0%{?suse_version}
%if 1%{?erlang_libdir:0}
%define erlang_libdir %{_libdir}/erlang/lib
%endif
%endif

%description
rebar is an Erlang build tool that makes it easy to compile and
test Erlang applications, port drivers and releases.

rebar is a self-contained Erlang script, so it's easy to distribute or even
embed directly in a project. Where possible, rebar uses standard Erlang/OTP
conventions for project structures, thus minimizing the amount of build
configuration work. rebar also provides dependency management, enabling
application writers to easily re-use common libraries from a variety of
locations (git, hg, etc).

%package src
Summary:        A sophisticated build-tool for Erlang projects that follows OTP principles
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
Provides:       %{name}-devel = %{version}
Obsoletes:      %{name}-devel < %{version}

%description src
rebar is an Erlang build tool that makes it easy to compile and
test Erlang applications, port drivers and releases.

%prep
%autosetup -p1 -n rebar-%{version}

%build
export REBAR_DEPS_PREFER_LIBS=1
make
if [ -e /usr/bin/strip-nondeterminism ] ; then
  # normalize timestamps in the zip file
  # that starts after 3 lines at offset 51 with "PK"
  zipoffs=$(perl -ne 'if(/\APK/){print $offs;exit 0} $offs+=length($_)' rebar)
  dd if=rebar of=rebar.zip bs=$zipoffs skip=1
  strip-nondeterminism rebar.zip
  dd if=rebar.zip of=rebar bs=$zipoffs seek=1 conv=notrunc
  rm rebar.zip
fi

%install
%if %{normal_build}
install -Dm755 rebar %{buildroot}%{_bindir}/rebar
# Install RPM macros:
install -Dm644 %{SOURCE1} %{buildroot}%{_rpmmacrodir}/macros.erlang-rebar
for dir in include ebin priv src ; do
  install -d %{buildroot}%{erlang_libdir}/rebar-%{mod_ver}/${dir}
  cp -r ${dir}/* %{buildroot}%{erlang_libdir}/rebar-%{mod_ver}/${dir}/
done
mkdir -p %{buildroot}%{_sysconfdir}/bash_completion.d
ln -s %{erlang_libdir}/rebar-%{mod_ver}/priv/shell-completion/bash/rebar %{buildroot}%{_sysconfdir}/bash_completion.d/rebar.sh
%endif

%check
%if %{testsuite_build}
# test is broken inside OBS environment due to lack of FQDN
rm -rf inttest/ct3
rm -rf inttest/ct_cover
# test is broken due to library path resolution problem
rm -rf inttest/proto_gpb
rm -rf inttest/neotoma1
# rebar is not compatible with hg 1.0.2 delivered by SLE <= 11
# these checks will thus fail -> delete them
%if 0%{?sles_version} > 0 && 0%{?sles_version} <= 11
rm -rf inttest/tdeps1
rm -rf inttest/tdeps2
%endif
# our erlang doesn't have diameter (see bnc#728667)
rm test/rebar_dia_tests.erl
%{_bindir}/rebar eunit
%{_bindir}/retest -l debug inttest
%{_bindir}/rebar xref
%endif

%if %{normal_build}
%files
%defattr(-,root,root)
%doc README.md THANKS rebar.config.sample
%license LICENSE
%{_bindir}/rebar
%{_rpmmacrodir}/macros.erlang-rebar
%dir %{erlang_libdir}/rebar-%{mod_ver}
%{erlang_libdir}/rebar-%{mod_ver}/ebin
%{erlang_libdir}/rebar-%{mod_ver}/include
%{erlang_libdir}/rebar-%{mod_ver}/priv
%{_sysconfdir}/bash_completion.d/rebar.sh

%files src
%defattr(-,root,root)
%{erlang_libdir}/rebar-%{mod_ver}/src
%endif

%changelog
* Wed May 22 2024 Simon Lees <sflees@suse.de>
- We use a linked copy of this package in some SUSE products and
  to do so correctly, we need to ensure a minimum of erlang 26
  Leap will soon get a versioned copy of erlang26 as well
* Thu Feb 22 2024 Michael Vetter <mvetter@suse.com>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Thu Jan  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- HACK: do not build the -testsuite flavor in distro projects (i.e
  in repositories called 'standard'). Allows to get fixes included
  in the distro while the test suite actually still fails
  (boo#1205140).
* Thu Aug 10 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add _multibuild: declare additional spec files as further flavors
  to build. Allows OBS to build those spec files without the need
  for linked packages.
* Wed Oct 12 2022 Matwey Kornilov <matwey.kornilov@gmail.com>
- Add 0001-Fix-rebar-xref-for-recent-Erlang.patch:
  fix testsuite
* Wed Jun 30 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Move rpm macros from /etc/rpm to %%{_rpmmacrodir} (boo#1185668).
* Sat Jan 16 2021 Matwey Kornilov <matwey.kornilov@gmail.com>
- Add rebar-0014-erl_interface-was-removed-in-Erlang-23.patch:
  erl_interface is missed since Erlang 23
* Thu Aug 16 2018 opensuse-packaging@opensuse.org
- Update to version 2.6.4+git20180201.b6d3094:
  * travis-ci: allow Dialyzer job to fail
  * travis-ci: update otp versions
  * travis-ci: enable 20.1
  * rebar_xref: ignore opaque type match Dialyzer warning
  * rebar_cover: ignore opaque type match Dialyzer warning
  * rebar_utils: fix Dialyzer warning
  * Run Dialyzer on Travis-CI
  * Log out success message with newlines
  * travis-ci: otp 20.0.2 -> 20.0.4
  * Revert "Drop crypto app reliance"
  * Remove profiler note
  * inttest/*: do not export_all
  * Fix ctsuite template
  * Improve pseudo-unique ct_run node name
  * Drop crypto app reliance
  * rebar.config: access retest repo via https
  * Fix Erlang 20 export_all warnings
  * Fix #634
  * travis-ci: test with Erlang 20.0.2
  * Properly skip apps with a .app.src.script file
  * Fix typo in eunit help.
* Thu Mar 29 2018 guillaume.gardet@opensuse.org
- Add _constraints file to avoid slow CPU to pass testsuite
* Wed Jul 12 2017 bwiedemann@suse.com
- Add reproducible.patch to use a constant build time in .beam files
- Normalize zip file timestamps in /usr/bin/rebar (boo#1047218)
* Fri Sep 30 2016 matwey.kornilov@gmail.com
- Update to version 2.6.4+git20160922.576e121:
  * Revert 'Treat port env vars as expandable only if they self reference'
  * Add necessary missing OSX flags for port driver linking
  * Prepare release 2.6.2
  * qc: lift experimental notice
  * port_compiler: consistently format default_env/0
  * Introduce and use compat random number module
  * Add an additional check for the existence of a 'rebar.beam' file during bootstrap run. Bootstrap fails on first run without any .beam files in the ebin folder.
  * port_compiler: generate clang compilation db
  * port_compiler: clean up compile_each()
  * port_compiler: auto-select C++ specific link template
  * Prepare release 2.6.3
  * Fix cdb processing when a file is skipped
  * rebar_utils: restore blank line
  * port_compiler: fix handling of multiple specs
  * Prepare release 2.6.4
  * Remove superfluous space in unabbrev error msg
  * Continuous integration on OTP 19.1
* Mon May  9 2016 matwey.kornilov@gmail.com
- Update to version 2.6.1+git20160413.9281b84:
  + Support rebar3-style deps
  + Add raw to VsnRegex-Free dep
  + add deprecated message
* Mon May  9 2016 matwey.kornilov@gmail.com
- BuildRoot should be common for both packages
* Sat Mar 19 2016 matwey.kornilov@gmail.com
- Update to version 2.6.1+git20160318.ef73556:
  + Optionally look for ct .spec files in the ct_dir that was specified
  + Introduce REBAR_VSN_CACHE_FILE env variable to load/save vsn cache
* Fri Mar 18 2016 matwey.kornilov@gmail.com
- Remove 0001-Find-all-deps-locally-first.patch:
  + use upstreamed alternative
- Remove 0002-Read-vsn-from-file.patch:
  + use upstreamed alternative
- Remove no-rebar-deps.patch: not needed anymore
* Fri Mar 18 2016 matwey.kornilov@gmail.com
- Update to version 2.6.1+git20160317.384af7e:
  + Add support for Windows integration testing
  + Update retest dependency url
  + Add neotoma regression test
  + Automatically clean neotoma-generated erl files Add myself to THANKS
  + Ensure ebin created for dia compiler
  + Add tests for dia compiler
  + Update regexp to account for newer OTP versions
  + Treat port env vars as expandable only if they self reference
  + Additional Common Test regression tests
  + Fix eunit_surefire crash with rebar eunit tests=...
  + Provide additional test coverage for surefire enabled eunit testing
  + Fix bug when running gcc in cross_sizeof
  + Introduce REBAR_DEPS_PREFER_LIBS env variable to alter search behaviour
* Sun Jan 17 2016 matwey.kornilov@gmail.com
- Update to version 2.6.1+git20160115.c534f8a:
  + fprof: document Cachegrind support
  + fprof: further document Cachegrind support
  + Add qualified name tests docs (see pr #119)
  + Fix windows eunit tests
  + Lock retest dependency
  + Allow windows release to use etc conf dir
  + xref: fix dialyzer warning introduced in 69802f63120
  + Provide additional debug logging on relup generation
  + Add the latest OTP 18 version to the Travis build
* Fri Oct 16 2015 matwey.kornilov@gmail.com
- erlang-rebar-src and erlang-rebar-obs-src should also be
  in conflict explicitly
* Thu Oct 15 2015 matwey.kornilov@gmail.com
- Update to version 2.6.1+git20151013.5d73a8d:
  + Add Windows continuous integration through AppVeyor
* Wed Oct  7 2015 matwey.kornilov@gmail.com
- Update to version 2.6.1+git20150928.365ac64:
  + Fix #544
  + Fix #544 even more.
  + Fix #544
  + Add erl_first_files to other first_files
  + Add test for eunit_first_files
  + Add report and verbose options for LFE compile
  + bump to 2.6.1
* Wed Sep 30 2015 dmueller@suse.com
- use m4 for substitution of the base package name,
  works around some defects in the source validator checks
* Fri Jul 24 2015 seife+obs@b1-systems.com
- fix "bad %%if condition" for non-SUSE distro builds
* Thu Jun 12 2014 matwey.kornilov@gmail.com
- Version 2.3.1
  - fix build for 17
* Wed Apr 16 2014 matwey.kornilov@gmail.com
- Add erlang-rebar-obs package to use it in OBS only.
  It does not require Internet.
- prjconf should be something like that:
  Substitute: erlang-rebar erlang-rebar-obs
* Wed Apr 16 2014 matwey.kornilov@gmail.com
- Version 2.2.0
* Sat Mar  1 2014 nkrinner@suse.com
- Added rpmlintc file to allow build to succeed with a file with
  source code
* Sun Feb  2 2014 matwey.kornilov@gmail.com
- updated to latest master (2.1.0 release)
* Mon Sep 30 2013 matwey.kornilov@gmail.com
- updated to latest master. some minor bugfixes
* Wed Jun 26 2013 matwey.kornilov@gmail.com
- add bash autocompletion, rename -devel to -src
* Wed Jun 26 2013 kruber@zib.de
- remove cyclic dependency to erlang-retest
  (a pre-build version is already bundled with rebar in ./inttest)
- fix SLE build (hg version is incompatible thus some tests fail)
* Wed Jun 26 2013 kruber@zib.de
- fix package build (require erlang-retest package for %%check)
  This dependency is cyclic, as erlang-retest needs rebar to build
  normally, here rebar is built and then retest (from git) which
  is only needed for the tests we don't have access to git from
  OBS though, try this way (or disable %%check).
* Mon Jun 17 2013 speilicke@suse.com
- Add %%changelog section
* Fri Apr  5 2013 speilicke@suse.com
- Fix %%rebar and %%rebar_compile macros to take further parameters
* Thu Apr  4 2013 speilicke@suse.com
- Move rebar-specific macros from erlang package to erlang-rebar
* Thu Apr  4 2013 speilicke@suse.com
- Added macros.erlang-rebar, which includes the following RPM macros:
  + %%erlang_rebar
- Install ebam and priv files
- Added devel package
* Wed Apr  3 2013 speilicke@suse.com
- Rename to erlang-rebar
- Use mode="disabled" source service and properly create a tarball
- General cleanup for Factory
* Sat Oct  6 2012 matwey.kornilov@gmail.com
- Cleaned up initial version
